@@ -1,6 +1,5 @@
 from Products.CMFCore.utils import getToolByName
 
-
 def install_browserlayer(context):
     setup = getToolByName(context, 'portal_setup')
     setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
@@ -9,10 +8,15 @@ def install_browserlayer(context):
 
 PREVIOUS = ('++resource++jquery-ui-1.8.min.js',
             '++resource++jquery-ui-1.7.min.js',
-            '++resource++jquery-ui-1.7.2.min.js',
-            '++resource++jquery-ui-1.7.3.min.js')
+            '++resource++jquery-ui-1.7.2.min.js')
 
 def portal_javascripts(context):
+    
     jsregistry = getToolByName(context, 'portal_javascripts')
     for PREV in PREVIOUS:
         jsregistry.unregisterResource(PREV)
+
+    setup = getToolByName(context, 'portal_setup')
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'jsregistry', run_dependencies=False,
+                                   purge_old=False)
